@@ -57,6 +57,7 @@ __all__ = (
     "ListFindingsReportsResponseTypeDef",
     "ListProfileTimesResponseTypeDef",
     "ListProfilingGroupsResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PutPermissionResponseTypeDef",
     "RemoveNotificationChannelResponseTypeDef",
@@ -191,6 +192,7 @@ ProfilingGroupDescriptionTypeDef = TypedDict(
         "createdAt": datetime,
         "name": str,
         "profilingStatus": "ProfilingStatusTypeDef",
+        "tags": Dict[str, str],
         "updatedAt": datetime,
     },
     total=False,
@@ -345,6 +347,10 @@ class ListProfilingGroupsResponseTypeDef(
     pass
 
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
